@@ -23,6 +23,7 @@
     StS[which(abs(StS)<1e-15)]<-0
     Sxx[which(abs(Sxx)<1e-15)]<-0
     vX0[which(abs(vX0)<1e-15)]<-0
+    vX0<-matrix(vX0,ncol=1,nrow=ncol(dfX))
     if (!(is.null(Merror)||is.na(Merror)||(sum(sum(abs(Merror)))<1e-15))||(length(vNAX)!=0)||(is.nan(LogLik)||is.na(LogLik)||(LogLik< -1000000)||is.infinite(LogLik))){## there is measurement error or something went wrong
 	D<-matrix(1,ncol=1,nrow=length(phylTree@term))%x%diag(1,ncol(dfX),ncol(dfX))
 	data<-c(t(as.matrix(dfX)[phylTree@term,]))
@@ -38,16 +39,20 @@
 		if (length(vNAX)>0){V<-V[-vNAX,-vNAX]}
 		V1<-pseudoinverse(V)
 		vX0<-pseudoinverse(t(D)%*%V1%*%D)%*%t(D)%*%V1%*%data
-		Edata<-rep(vX0,nrow(T))
+		vX0[which(abs(vX0)<1e-15)]<-0
+		Edata<-rep(vX0,nrow(T))		
+		vX0<-matrix(vX0,ncol=1,nrow=ncol(dfX))
 		if (length(vNAX)>0){Edata<-Edata[-vNAX]}
-		LogLik<-(-1)*dmvnorm(data,mean=Edata,sigma=V,log=TRUE)
+		tryCatch({
+		    LogLik<-(-1)*dmvnorm(data,mean=Edata,sigma=V,log=TRUE)
+		},error=function(e){})
 		if (is.nan(LogLik)||is.na(LogLik)||(LogLik> 1000000)||is.infinite(LogLik)){LogLik<- 1000000}
 		LogLik
 	    },T=phylTree@branch.times,Merror=Merror,data=data,D=D,vNAX=vNAX);
 	    optPar<-optSxx$par
 	    LogLik<- (-1)*optSxx$value
-	    },error=function(e){print(paste("Error in BM optim ",e))}
-	)	
+	    },error=function(e){print(paste("Error in BM optim ",e))}	
+	)
 	if (!is.na(optPar[1])){
 	    StS<-.sym.par(optPar,ncol(dfX))
 	    Sxx<-t(chol(StS))
